/* Copyright (c) 2002-2005, The Ohio State University. All rights
 * reserved.
 *
 * This file is part of the MVAPICH software package developed by the
 * team members of The Ohio State University's Network-Based Computing
 * Laboratory (NBCL), headed by Professor Dhabaleswar K. (DK) Panda.
 *
 * For detailed copyright and licencing information, please refer to the
 * copyright file COPYRIGHT_MVAPICH in the top level MPICH directory.
 *
 */

/*
 * vapi_const.h 
 * 
 * This file contains "tunable parameters" for VAPI. A lot of work 
 * needs to be done to find out what are the right values, and in 
 * fact whether this is the right set of knobs. Many are settable 
 * from the command line and
 * passed to the individual processes as environment variables.
 */

#ifndef _VAPI_CONST_H
#define _VAPI_CONST_H

/*#define CO_PRINT */
#ifdef CO_PRINT
#define co_print(arg...)  \
do {                        \
   printf("[%d]", viadev.me);  \
   printf(arg); \
} while (0)
#else
#define co_print(arg...)
#endif

/*
#define NUM_ADDR_BITS           (32)
#define MASK_ADDR_BITS          (0xffffffff)
*/
/* The length of QP representation in characters, could be 4 HEX */
#define QPLEN_XDR               (8)

#define VIADEV_DEFAULT_MTU             (MTU1024)
#define VIADEV_MAX_RDMA_SIZE		(1048576)  
#define VIADEV_DEFAULT_QP_OUS_RD_ATOM  (1)

#define VIADEV_DEFAULT_PSN             (0)
#define VIADEV_DEFAULT_PKEY_IX         (0) 
#define VIADEV_DEFAULT_P_KEY           (0x0)
#define VIADEV_DEFAULT_MIN_RNR_TIMER   (0x18)
#define VIADEV_DEFAULT_SERVICE_LEVEL   (0)
#define VIADEV_DEFAULT_TIME_OUT        (10)

#define VIADEV_DEFAULT_STATIC_RATE     (0)

#define VIADEV_DEFAULT_SRC_PATH_BITS   (0)

#define VIADEV_MAX_FAST_EAGER_SIZE 255

/* To handle congestion in larger clusters */
#define VIADEV_DEFAULT_RETRY_COUNT     (7)

/* Set to infinite */
#define VIADEV_DEFAULT_RNR_RETRY       (7)

/*
#define VIADEV_DEFAULT_R_KEY           (0x0)
#define VIADEV_DEFAULT_L_KEY           (0x0)
#define VIADEV_MAX_NUM_DHANDLE		(10000)
*/
#define VIADEV_DEFAULT_MAX_SG_LIST	(20)
#define  VIADEV_DEFAULT_MAX_RDMA_DST_OPS (16)

#define HOSTNAME_LEN (255)

#ifdef _IA32_
    #ifdef _SMALL_CLUSTER
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #elif defined (_MEDIUM_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (16)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (16384)
    #elif defined (_LARGE_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (16)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (16384)
    #else
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #endif
#elif defined (_EM64T_)
    #ifdef _SMALL_CLUSTER
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #elif defined (_MEDIUM_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (16)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #elif defined (_LARGE_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (8)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (8192)
    #else
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #endif
#elif defined (_IA64_)
    #ifdef _SMALL_CLUSTER
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #elif defined (_MEDIUM_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (16)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (16384)
    #elif defined (_LARGE_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (16)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (8192)
    #else
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #endif
#elif defined (_X86_64_)
    #ifdef _SMALL_CLUSTER
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #elif defined (_MEDIUM_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (16)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (16384)
    #elif defined (_LARGE_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (16)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (8192)
    #else
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #endif
#elif defined (MAC_OSX)
    #ifdef _SMALL_CLUSTER
    #define VIADEV_NUM_RDMA_BUFFER            (128)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #elif defined (_MEDIUM_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (64)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (16384)
    #elif defined (_LARGE_CLUSTER)
    #define VIADEV_NUM_RDMA_BUFFER            (32)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (8192)
    #else
    #define VIADEV_NUM_RDMA_BUFFER            (128)
    #define DEFAULT_RENDEZVOUS_THRESHOLD      (VBUF_BUFFER_SIZE - \
            sizeof(viadev_packet_eager_start))
    #endif
#endif

#define VIADEV_PREPOST_DEPTH 64
#define VIADEV_VBUF_MIN_POOL_SIZE 100
#define VIADEV_PREPOST_RENDEZVOUS_EXTRA VIADEV_PREPOST_DEPTH

#ifdef MCST_SUPPORT
#define DEFAULT_MAX_CQ_SIZE (40000)
#define DEFAULT_MAX_WQE    (10000)
#define DEFAULT_FLOW_LABEL      (0)
#define DEFAULT_TRAFFIC_CLASS   (0)
#define DEFAULT_HOP_LIMIT       (63)
#endif

#endif                          /* _VAPI_CONST_H */
